.. image:: https://travis-ci.org/rasmunk/nbi-projects-site.svg?branch=master
    :target: https://travis-ci.org/rasmunk/nbi-projects-site

=================
nbi-projects-site
=================

Website for the `escience <www.nbi.ku.dk/Forskning/escience/>`_  department at
`KU <https://www.ku.dk>`_.
It is used to list projects within and in collaboration with the department.
This includes potential bachelor/master projects that students can undertake during their studies.
It relies on the `projects-site <https://github.com/rasmunk/projects-site>`_
repo for the underlying features for providing the website.

Example of it can be seen at `eScience Projects <https://projects.escience.dk>`_
